"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.storeConnectionData = storeConnectionData;
exports.fetchConnectionData = fetchConnectionData;
exports.deleteConnectionData = deleteConnectionData;
exports.sendMessageToConnection = sendMessageToConnection;
const aws_sdk_1 = require("aws-sdk");
const constants_1 = require("../constants");
async function storeConnectionData(db, config, connectionID, data) {
    await db
        .put({
        TableName: config.resourceNames.connectionsStore,
        Item: {
            ...data,
            [constants_1.connectionsStoreAttributes.partitionKey]: connectionID,
        },
    })
        .promise();
}
async function fetchConnectionData(db, config, connectionID) {
    const response = await db
        .get({
        TableName: config.resourceNames.connectionsStore,
        Key: { [constants_1.connectionsStoreAttributes.partitionKey]: connectionID },
        ConsistentRead: true,
    })
        .promise();
    return response.Item;
}
async function deleteConnectionData(db, config, connectionID) {
    await db
        .delete({
        TableName: config.resourceNames.connectionsStore,
        Key: { [constants_1.connectionsStoreAttributes.partitionKey]: connectionID },
    })
        .promise();
}
async function sendMessageToConnection(config, connectionID, data) {
    await new aws_sdk_1.ApiGatewayManagementApi({
        endpoint: config.mustGetEnvironmentVar(constants_1.environmentVarNames.websocketAPIURL),
    })
        .postToConnection({
        ConnectionId: connectionID,
        Data: JSON.stringify(data),
    })
        .promise();
}
